# Operator - SPL Token Transfer

## Requirements

{{ #include ../../../../operator-requirements.md:requirements }}

* Online machine

* [High Visibility Storage](TODO): plastic container or bag that's used to keep items while not in use in a visible location like the middle of a desk.

* [Quorum PGP key pairs](../../key-types.md#quorum-pgp-keypair) 

* [Ceremony SD card](../../ceremony-sd-card-provisioning.md)

## Procedure

1. Enter the designated location with the quorum of operators and all required equipment

1. Lock access to the location - there should be no inflow or outflow of people during the ceremony

1. Place Ceremony SD card in High Visibility Storage

1. Retrieve sealed Air-Gapped bundle, polaroid of tamper evidence, and online laptop from locked storage

{{ #include ../../../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Place all contents except for the laptop into High Visibility Storage

### Online Machine: Acquire Nonce

1. Turn on online machine

1. Retrieve the Ceremony SD card from High Visibility Storage and plug it into the computer

1. Run the command: `icepick workflow sol broadcast --nonce-address=<nonce_address>`

	* The nonce address is found on the Ceremony SD card

	* Await completion message before removing Ceremony SD card

	* This command will set the computer into "awaiting mode", which will broadcast the signed transaction from the SD card once it's plugged back in after the workflow payloads are signed on the offline machine

### Offline Machine: Create and Sign Transaction

1. Retrieve AirgapOS SD card and plug it into the air-gapped machine

1. Boot the computer  

1. Unplug the AirgapOS SD card and place it in High Visibility Storage

1. Retrieve Ceremony SD card from High Visibility Storage and plug it into the air-gapped machine 

1. Verify keyring data from the Ceremony SD card:

	1. Import keys into the system

		* `gpg --import keys/all/*.asc`

	1. Plug in the operator's smartcard, and ensure it is loaded:

		* `gpg --card-status`

	1. Print the list of trusted keys:

		* `sq-wot --gpg list`

	1. Repeat for every operator, ensuring all keys are cross-trusted.

	1. Terminate `gpg-agent`: `killall gpg-agent`

1. Verify all signatures for the workflow data:

	* `for file in <payload.json>.*.sig; do echo "Verifying: $file"; gpg --verify "${file}" "<payload.json>"; done`

	* Ensure that the script doesn't output any "WARNING" messages to the console. If it does, abort the ceremony and initiate incident response.

1. Start Keyfork using the relevant Shardfile:

	* `keyfork recover shard --daemon /media/external/shard.asc`

	* The Shardfile may be named something else. Use `find /media/external -type f -name '*shard*.asc'` to list all files.

1. Follow on screen prompts

1. Run the `icepick` command with the transaction payload

	* `icepick workflow sol transfer-token --input-file=<(jq .values <payload.json>)` 

	* Follow on screen prompts

1. Unplug the Ceremony SD card and place it in High Visibility Storage

### Broadcast Transaction: Online Machine

1. Retrieve Ceremony SD from High Visibility Storage and plug it into online machine

1. The still running broadcast command on the online machine will broadcast the transaction automatically

1. The url that's found in the response after a successful broadcast should be reviewed and committed to the ceremony repository

1. Unplug the Ceremony SD card and place it in High Visibility Storage

### Repeat

1. You may repeat previous steps as many times as necessary to process all workflow payloads

## Finalization

1. Shut down online machine

1. Shut down the air gapped machine

### Sealing

1. Gather all the original items that were in the air-gapped bundle:

    * Air-gapped computer

    * AirgapOS SD card

{{ #include ../../../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}
